MethodChannelFlutterLocalPrefs class

An implementation of FlutterLocalPrefsPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

contain({required String key, bool isPersistent = false}) → Future<bool>
override
getBool({required String key, bool isPersistent = false}) → Future<bool>
override
getDouble({required String key, bool isPersistent = false}) → Future<double>
override
getInt({required String key, bool isPersistent = false}) → Future<int>
override
getLong({required String key, bool isPersistent = false}) → Future
override
getString({required String key, bool isPersistent = false}) → Future<String>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove({required String key, bool isPersistent = false}) → Future
override
removeAll({bool isPersistent = false}) → Future
override
saveData({required Object object, required String key, bool isPersistent = false}) → Future
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited